#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}

%if "%flavor" == "ui"
%define pname_suff -ui
%endif

%define ibdm_major 1
%define upstream_ver 1.5.7
%define tar_rel 0.2

Name:           ibutils%{?pname_suff}
Summary:        OpenIB Mellanox InfiniBand Diagnostic Tools
License:        BSD-3-Clause OR GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
Version:        %upstream_ver.%tar_rel
Release:        11.9
Source0:        https://www.openfabrics.org/downloads/ibutils/ibutils-%upstream_ver-%tar_rel.gbd7e502.tar.gz
Source1:        ibutils-rpmlintrc
#PATCH-FIX-UPSTREAM Fix non-void functions returning no value
Patch1:         ibutils-1.2-retval.patch
#PATCH-FIX-UPSTREAM Extend the check to include tk 8.6
Patch2:         ibutils-tk-8.6.patch
#PATCH-FIX-UPSTREAM Prepare for autoreconf run
Patch4:         ibutils-autotools.patch
#PATCH-FIX-UPSTREAM Do not link ibdmsh statically and remove rpath
Patch5:         ibutils-no_special_ldflags_for_ibdmsh.patch
# Add --disable-ibdiagui option to allow for split builds
Patch6:         ibutils-diagui.patch
Patch7:         ibutils-fix-build-dependency.patch
Patch8:         ibis-drop-multiple-definition-of-IbisObj.patch
Patch9:         ibutils-ibis-PIE.patch
URL:            http://www.openfabrics.org
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  chrpath
BuildRequires:  fdupes
BuildRequires:  gawk
BuildRequires:  gcc-c++
BuildRequires:  libibverbs-devel
BuildRequires:  libtool
BuildRequires:  opensm-devel
%if "%flavor" == "ui"
BuildRequires:  graphviz-tcl
BuildRequires:  swig
BuildRequires:  tk-devel
Requires:       graphviz-tcl
Requires:       ibutils = %version
%else
BuildRequires:  tcl-devel
%endif

%description
%if "%flavor" == ""
The ibutils package provides a set of diagnostic tools that check the health
of an InfiniBand fabric.

Package components:
ibis:     IB interface - A TCL shell that provides interface for sending various
          MADs on the IB fabric. This is the component that actually accesses
          the IB Hardware.

ibdm:     IB Data Model - A library that provides IB fabric analysis.

ibmgtsim: An IB fabric simulator. Useful for developing IB tools.

ibdiag:   This package provides two tools which provide the user interface
          to activate the above functionality:
            - ibdiagnet:  Performs various quality and health checks on the IB
                          fabric.
            - ibdiagpath: Performs various fabric quality and health checks on
                          the given links and nodes in a specific path.
%else
The ibutils-ui package provides a set of graphical UI tools that check the health
of an InfiniBand fabric.

Package components:
ibdiag:   This package provides one tool which provide the user interface
          to activate the above functionality:
            - ibdiagui:   A GUI wrapper for ibdiagnet and ibdiagpath.
%endif

%package        devel
Summary:        SDK for OpenIB Mellanox InfiniBand Diagnostic Tools
Group:          Development/Libraries/C and C++
Requires:       %name = %version
Requires:       libibdm%ibdm_major = %version

%description    devel
ibutils provides IB network and path diagnostics.

%package     -n libibdm%ibdm_major
Summary:        Infiniband Data Model library
Group:          System/Libraries

%description -n libibdm%ibdm_major
This package contains shared libraries for the IB utils.

%prep
%setup -q -n ibutils-%upstream_ver
%patch1
%patch2
%patch4
%patch5
%patch6
%patch7
%patch8
%patch9 -p1

%build
autoreconf -fi
./autogen.sh
%if "%flavor" == ""
%configure --with-graphviz-lib=%_libdir --disable-static --disable-ibdiagui
%make_build
%else
%configure --with-graphviz-lib=%_libdir --disable-static
%make_build -Cibdiag
%endif

%install
export NO_BRP_TCL_INDEX_CHECK=true
%if "%flavor" == ""
%make_install
%else
%make_install -Cibdiag/
rm -f %buildroot%_bindir/git_version.tcl %buildroot%_bindir/ibdiagnet %buildroot%_bindir/ibdiagpath
rm -Rf %buildroot%_libdir/ibdiagnet*  %buildroot%_libdir/ibdiagpath*
rm -f %buildroot%_mandir/man1/ibdiagnet.1* %buildroot%_mandir/man1/ibdiagpath.1*
%endif
%fdupes -s %buildroot%_libdir
rm -f %buildroot%_libdir/*.la %buildroot%_libdir/*.a

%post -n libibdm%ibdm_major -p /sbin/ldconfig
%postun -n libibdm%ibdm_major -p /sbin/ldconfig

%if "%flavor" == ""

%files
%license COPYING
%_bindir/*
%_libdir/ibdiagnet%upstream_ver
%_libdir/ibdiagpath%upstream_ver

%files -n libibdm%ibdm_major
%_libdir/libibdm.so.*
%_libdir/libibdmcom.so.*
%_libdir/libibsysapi.so.*
%_libdir/ibdm%upstream_ver
%_libdir/ibis%upstream_ver

%files devel
%_includedir/ibdm
%_libdir/libibdm.so
%_libdir/libibdmcom.so
%_libdir/libibsysapi.so
%_mandir/man1/*

%else

%files
%license COPYING
%_bindir/ibdiagui
%_libdir/ibdiagui%upstream_ver
%_mandir/man1/ibdiagui*
%endif

%changelog
* Tue Sep 14 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Unify changelog with SLE15
* Thu Apr 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim old rpm constructs.
- Update descriptions.
* Thu Apr 15 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Hardening: Link ibis executable with -pie (bsc#1184123).
  - Added ibutils-ibis-PIE.patch
* Sun Jun  7 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Add ibis-drop-multiple-definition-of-IbisObj.patch to fix compilation with GCC10
* Tue May 28 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Unify changelog with SLE12
* Tue May 28 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Fix older changelog entry that silently added a patch
- Use %%license for COPYING
* Tue Sep 18 2018 nmoreychaisemartin@suse.com
- Switch to multibuild system
- Remove empty lines from ibutils-ui description (bsc#1092319)
* Tue Aug 21 2018 nmoreychaisemartin@suse.com
- Add ibutils-fix-build-dependency.patch to fix compilation
  with -j1 (bsc#1102911)
* Wed May 23 2018 nmoreychaisemartin@suse.com
- Move ibdm and ibis library directories to libibdm1 package (bsc#1092166)
* Fri Jun  2 2017 nmoreychaisemartin@suse.com
- Fix ibutils-diagui.patch to not build ibdiagui
  with the ibutils package.
* Thu Jun  1 2017 jengelh@inai.de
- Scriptlets and %%packages need not be wrapped in %%if.
* Fri Apr 28 2017 jengelh@inai.de
- Normalize all macros
- Replace "1 tool" by one tool for better reading
* Thu Mar 30 2017 nmoreychaisemartin@suse.com
- Add ibutils-diagui.patch to allow UI less compilation
- Add a separate ibutils-ui package for UI tools. BSC #1030891
* Mon Feb 23 2015 mgorse@suse.com
- Add COPYING to package docs.
* Fri Feb 13 2015 p.drouand@gmail.com
- Update to version 1.5.7-0.2
  * No changelog available
- Remove ibutils-add_shebang.patch and ibutils-code_cleanup.patch
  not needed anymore
- Use download Url as source
* Thu Aug 21 2014 pth@suse.de
- Ibutils Makefiles are missing dependencies so successfull builds
  depend on timing so build in single job until fixed.
* Fri Jul 18 2014 pth@suse.de
- Add ibutils-no_special_ldflags_for_ibdmsh.patch to
  remove the bogus rpath from ibdmsh and that vein do not link
  ibdmsh statically.
* Thu Jul 17 2014 pth@suse.de
- Do not build and install the dynamic library so remove all
  traces.
- Remove .la files as they were only needed for the static libs.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue May 13 2014 pth@suse.de
- Update to 1.5.7-0.2.gbd7e502 from OFED 3.12 RC2.
  No change log present.
- Added the fix for two cases of forbidden implicit const removal
  to ibutils-code_cleanup.patch.
- Remove ibutils-add_shebang.patch as the file it pathed doesn't
  exist anymore.
* Wed Mar  5 2014 pth@suse.de
- Add COPYING to package docs.
* Fri Jan 17 2014 pth@suse.de
- Update to OFED 3.12 daily snapshot
- Use spdx.org format for license specification
* Wed Aug 28 2013 pth@suse.de
- Add ibutils-tk-8.6.patch to include tk 8.6 in the check for accetable
  tk versions.
- Add ibutils-add_shebang.patch to add a shebang to git_version.tcl
  which is installed in _bindir.
- Run fdupes to eleminate file duplication.
- Add a rpmlintrc file to silence useless warnings.
- Add ibutils-autotools.patch to modify the neccessary files
  so that autoreconf can be called.
- (Build)Require graphviz-tcl as ibdiag won't work correctly without
  the graphviz tcl plugin.
* Tue Sep 11 2012 pth@suse.de
- Update to 1.5.7-0.1.g05a9d1a from OFED 1.5.4.1:
  New Features:
  * Added scripts that convert OSM dump files for ibdmchk
  ibutils: added support for GUIDInfo MAD in ibis and simulator
  Major Bugs Fixed:
  * ibmgtsim: fixed various bugs with running simulations
  * ibutils: fixed rpmbuild with and w/o ibmgtsim
  Known Issues:
  * Ibdiagnet "-wt" option may generate a bad topology file when
    running on a cluster that contains complex switch systems.
  * ibutils works only partially on any distro with TCL 8.5.
    ibdiagnet/ibdiagpath/ibis don't work with TCL 8.5 due to a change
    in TCL behavior: the built-in TCL function "dump" on TCL 8.5
    always includes field names.
    Until the fix, any user script that uses ibis needs to be fixed
    in order to function correctly on TCL 8.5
- Adapt the patch.
- Package static library in a devel-static package.
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Mon May 24 2010 jjolly@novell.com
- Updated to v1.5.4 from OFED 1.5.1
- Removed patch for libreplace
- Updated the retval patch to include a fix to CredLoops.cpp
* Fri May 14 2010 jjolly@novell.com
- Updated the ibutils tarball to the one found in the OFED 1.4.2
  release.  There is no version change as the ibutils package in
  OFED changed, but did not change version numbers.
* Thu Oct 16 2008 jjolly@suse.de
- Updated with version from OFED 1.3.1 release
* Fri Feb 29 2008 jjolly@suse.de
- Updated with release from OFED 1.3 GA
* Tue Jan 29 2008 jjolly@suse.de
- Updated with release from OFED 1.3 rc2 (still v1.2)
* Mon Jul  9 2007 hvogel@suse.de
- Use correct version number
* Wed Jul  4 2007 hvogel@suse.de
- add GPL COPYING file [#288790]
* Mon Jul  2 2007 hvogel@suse.de
- Update to the OFED 1.2 release
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.0
